@@ -657,9 +657,16 @@ check_dimensions.shifts <- function(p, shifts){
 #' @title Find a reasonable grid for alpha
 #' 
 #' @description Grid so that 
-#' ln(2)*quantile(d_ij)/factor_up_alpha < t_{1/2} < factor_down_alpha * ln(2) * h_tree
+#' 2*ln(2)*quantile(d_ij)/factor_up_alpha < t_{1/2} < factor_down_alpha * ln(2) * h_tree
 #' Ensures that for alpha_min, it is almost a BM, and for alpha_max,
 #' almost all the tips are decorrelated.
+#' 
+#' @details
+#' If \code{quantile_low_distance=0}, then \code{quantile(d_ij)=min(d_ij)}, and, for any
+#' two tips i,j, the correlation between i anf j is bounded by exp(-factor_up_alpha/2).
+#' Those values of alpha will be used for the re-scaling of the tree, which has an 
+#' exponential term in exp(2*alpha*h). The function makes sure that this number is
+#' below the maximal float allowed (equals to \code{.Machine$double.xmax}).
 #'
 #' @param phy phylogenetic tree of class "\code{phylo}"
 #' @param alpha fixed vector of alpha values if already known. Default to NULL.
@@ -673,6 +680,8 @@ check_dimensions.shifts <- function(p, shifts){
 #'     
 #' @return A grid of alpha values
 #' 
+#' @seealso \code{\link{transform_branch_length}}, \code{\link{.Machine}}
+#' 
 #' @export
 #' 
 ##
@@ -688,6 +697,11 @@ find_grid_alpha <- function(phy, alpha = NULL,
   h_tree <- node.depth.edgelength(phy)[1]
   alpha_min <- 1 / (factor_down_alpha * h_tree)
   alpha_max <- factor_up_alpha / (2 * d_min)
+  alpha_max_machine <- log(.Machine$double.xmax^0.98)/(2*h_tree)
+  if (alpha_max > alpha_max_machine){
+    warning("The chosen alpha_max was above the machine precision. Taking alpha_max as the largest possible on this machine.")
+    alpha_max <- alpha_max_machine
+  }
   if (log_transform){
     return(c(0, exp(seq(log(alpha_min), log(alpha_max), length.out = nbr_alpha))))
   } else {
