@@ -240,14 +240,17 @@ edgelabels_home <- function (text, edge, adj = c(0.5, 0.5), frame = "rect",
 #' @param show.tip.label whether to show the tip labels. Default to FALSE.
 #' @param label_cex if \code{show.tip.label=TRUE}, the size of the labels. Default
 #' to 0.5.
+#' @param label_font if \code{show.tip.label=TRUE}, the font of the labels (see \link{par}).
 #' @param label_offset if \code{show.tip.label=TRUE}, the size of the offset between
 #' the tree and the labels. Default to 0.
 #' @param axis_cex cex for the label values of the plot. Default to 0.7.
+#' @param axis_las las for the label values of the plot. Default to 0 (see \link{par}).
 #' @param edge.width width of the edge. Default to 1.
 #' @param margin_plot vector giving the margin to around the plot.
 #' Default to \code{c(0, 0, 0, 0)}.
 #' @param gray_scale if TRUE, the colors are replaced by a gray scale.
 #' Default to FALSE.
+#' @param root.edge a logical indicating whether to draw the root edge (defaults to TRUE)
 #' @param ... further arguments to be passed to \code{\link{plot.phylo}}.
 #' 
 #' 
@@ -282,11 +285,14 @@ plot.PhyloEM <- function(x,
                          alpha_border = 70,
                          show.tip.label = FALSE,
                          label_cex = 0.5,
+                         label_font = 1,
                          label_offset = 0,
                          axis_cex = 0.7,
+                         axis_las = 0,
                          edge.width = 1,
                          margin_plot = NULL,
                          gray_scale = FALSE,
+                         root.edge = TRUE,
                          ...){
   ## Checking consistency
   if (plot_ancestral_states && length(traits) > 1) stop("Ancestral state plotting is only allowed for one single trait. Please select the trait you would like to plot with argument 'traits' (see documentation).")
@@ -307,7 +313,14 @@ plot.PhyloEM <- function(x,
   }
   # If on trait, select relevent quantities
   if (length(traits) == 1){
-    if (length(as.vector(params$selection.strength)) == 1) params$selection.strength <- diag(rep(params$selection.strength, x$p))
+    if (length(as.vector(params$selection.strength)) == 0) params$selection.strength <- 0
+    if (length(as.vector(params$selection.strength)) == 1){
+      if (x$p == 1){
+        dim(params$selection.strength) <- c(1,1)
+      } else {
+        params$selection.strength <- diag(rep(params$selection.strength, x$p))
+      }
+    }
     params <- split_params_independent(params)
     params <- params[[traits]]
   }
@@ -348,6 +361,7 @@ plot.PhyloEM <- function(x,
                            value_in_box = value_in_box,
                            shifts_cex = shifts_cex,
                            axis_cex = axis_cex,
+                           axis_las = axis_las,
                            margin_plot = margin_plot,
                            color_shifts_regimes = color_shifts_regimes,
                            # shifts_regimes = shifts_regimes,
@@ -357,11 +371,13 @@ plot.PhyloEM <- function(x,
                            ancestral_cex = ancestral_cex,
                            ancestral_pch = ancestral_pch,
                            label_cex = label_cex,
+                           label_font = label_font,
                            show.tip.label = show.tip.label,
                            # underscore = underscore,
                            # label.offset = label.offset,
                            ancestral_as_shift = ancestral_as_shift,
                            gray_scale = gray_scale,
+                           root.edge = root.edge,
                            ...)
 }
 
@@ -382,6 +398,7 @@ plot.data.process.actual <- function(Y.state, phylo, params,
                                      value_in_box = TRUE,
                                      shifts_cex = 1,
                                      axis_cex = 0.7,
+                                     axis_las = 0,
                                      margin_plot = NULL,
                                      color_shifts_regimes = FALSE,
                                      # shifts_regimes = NULL,
@@ -391,11 +408,13 @@ plot.data.process.actual <- function(Y.state, phylo, params,
                                      ancestral_cex = 2,
                                      ancestral_pch = 19,
                                      label_cex = 1,
+                                     label_font = 1,
                                      show.tip.label = FALSE,
                                      underscore = FALSE,
                                      label.offset = 0,
                                      ancestral_as_shift = TRUE,
                                      gray_scale = FALSE,
+                                     root.edge = TRUE,
                                      ...){
   # ## Save curent par
   # .pardefault <- par(no.readonly = T)
@@ -490,7 +509,7 @@ plot.data.process.actual <- function(Y.state, phylo, params,
   phylo$root.edge <- quantile(phylo$edge.length, quant.root)
   # Plot tree
   if (is.null(Y.state)){
-    plot(phylo, show.tip.label = show.tip.label, root.edge = TRUE, 
+    plot(phylo, show.tip.label = show.tip.label, root.edge = root.edge, 
          edge.color = as.vector(color_edges),
          edge.width = edge.width, ...)
     lastPP <- get("last_plot.phylo", envir = .PlotPhyloEnv)
@@ -504,7 +523,7 @@ plot.data.process.actual <- function(Y.state, phylo, params,
     x.lim.max <- h_p + p_dim * h_p / 3 + size_labels
     y.lim.min <- -ntaxa/10
     y.lim.max <- ntaxa + ntaxa/10
-    plot(phylo, show.tip.label = FALSE, root.edge = TRUE, 
+    plot(phylo, show.tip.label = FALSE, root.edge = root.edge, 
          x.lim = c(0, x.lim.max), 
          y.lim = c(y.lim.min, y.lim.max),
          edge.color = as.vector(color_edges),
@@ -545,7 +564,9 @@ plot.data.process.actual <- function(Y.state, phylo, params,
       axis(1, at = pos_last_tip + eccart_g + range(Y.plot, na.rm = TRUE),
            labels = round(range(Y.state[t, ], na.rm = TRUE), digits = 2),
            pos = y.lim.min + ntaxa/15, 
-           cex.axis = axis_cex, padj = -0.5)
+           cex.axis = axis_cex,
+           # padj = -0.5,
+           las = axis_las)
       # segments(pos_last_tip + eccart_g, y.lim.min + ntaxa/15,
       #          pos_last_tip + eccart_g + unit, y.lim.min + ntaxa/15,
       #          lwd = 2)
@@ -553,15 +574,15 @@ plot.data.process.actual <- function(Y.state, phylo, params,
       #      "Unit", cex = lastPP$cex,
       #      pos = 2)
       # characters
-      segments(pos_last_tip + eccart_g, lastPP$yy[1:ntaxa][!miss],
-               pos_last_tip + eccart_g + Y.plot[!miss], lastPP$yy[1:ntaxa][!miss],
-               col = as.vector(color_characters)[!miss],
+      segments(pos_last_tip + eccart_g, lastPP$yy[1:ntaxa][!miss[t, ]],
+               pos_last_tip + eccart_g + Y.plot[!miss[t, ]], lastPP$yy[1:ntaxa][!miss[t, ]],
+               col = as.vector(color_characters)[!miss[t, ]],
                lwd = edge.width)
       # missing ones as dotted
       if (any(miss)){
-        segments(pos_last_tip + eccart_g, lastPP$yy[1:ntaxa][miss],
-                 pos_last_tip + eccart_g + Y.plot[miss], lastPP$yy[1:ntaxa][miss],
-                 col = as.vector(color_characters)[miss],
+        segments(pos_last_tip + eccart_g, lastPP$yy[1:ntaxa][miss[t, ]],
+                 pos_last_tip + eccart_g + Y.plot[miss[t, ]], lastPP$yy[1:ntaxa][miss[t, ]],
+                 col = as.vector(color_characters)[miss[t, ]],
                  lwd = edge.width,
                  lty = 3) 
       }
@@ -577,7 +598,8 @@ plot.data.process.actual <- function(Y.state, phylo, params,
       if (!exists("color_characters_regimes")) color_characters_regimes <- color_characters
       text(x.lim.max.data, lastPP$yy[1:ntaxa], phylo$tip.label, 
            cex = label_cex, pos = 4,
-           col = as.vector(color_characters_regimes))
+           col = as.vector(color_characters_regimes),
+           font = label_font)
     }
   }
   ## Ancestral states
